@@ -24,6 +24,7 @@ __all__ = ["TweetDownloaderThread"]
 
 
 import datetime
+import math
 import threading
 import time
 
@@ -109,7 +110,7 @@ class TweetDownloaderThread(threading.Thread):
                 wait_seconds = (
                     exception.reset_time - datetime.datetime.now(datetime.timezone.utc)
                 ).total_seconds()
-                for _ in range(wait_seconds):
+                for _ in range(math.ceil(wait_seconds)):
                     time.sleep(1)
                     if self.shutdown.is_set():
                         break
